EncodedSecretPoint

Struct EncodedSecretPoint 

pub struct EncodedSecretPoint<E: Curve>(/* private fields */);
Bytes representation of a secret elliptic point. See SecretPoint for more information

This representation is automatically zeroed on drop, and doesn’t implement some vartime methods. You can still access the underlying bytes by calling .as_ref(). This bypasses all the secrecy guarantees given by this struct.

Implementations

Source

impl<E: Curve> EncodedSecretPoint<E>

pub fn new(point: EncodedPoint<E>) -> Self

Wrap a non-secret representation

pub fn as_nonsecret_bytes(&self) -> &[u8]

Obtain the reference to the encoded bytes. This bypasses all the secrecy guarantees, so be careful when handling them; ideally this reference should not be held for longer than one expression

pub fn as_nonsecret(&self) -> &EncodedPoint<E>

Obtain the reference to the encoded point, which you can use as bytes when necessary. This bypasses all the secrecy guarantees, so be careful when handling the resulting value; ideally this reference should not be held for longer than one expression