pub struct NonZero<T>(/* private fields */);Implementations
Sourceimpl<T> NonZero<T>
impl<T> NonZero<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Returns wrapped value
Sourceimpl<E: Curve> NonZero<Point<E>>
impl<E: Curve> NonZero<Point<E>>
Sourcepub fn from_point(point: Point<E>) -> Option<Self>
pub fn from_point(point: Point<E>) -> Option<Self>
Constructs non-zero point
Returns None if point is zero
Sourcepub fn ct_from_point(point: Point<E>) -> CtOption<Self>
pub fn ct_from_point(point: Point<E>) -> CtOption<Self>
Constructs non-zero point (constant time)
Returns None if point is zero
Sourceimpl<E: Curve> NonZero<Scalar<E>>
impl<E: Curve> NonZero<Scalar<E>>
Sourcepub fn random<R: RngCore>(rng: &mut R) -> Self
pub fn random<R: RngCore>(rng: &mut R) -> Self
Generates random non-zero scalar
Guarantees
- Uniform distribution
Output scalar is uniformly distributed (given that provided PRNG outputs uniformly distributed bytes), with possible negligible bias respective to curve target security level - Constant-time
Random generation algorithm does not branch on input randomness, and in particular, it does not use rejection-sampling strategy (might not be the case with negligible probability respective to the curve target security level1) - Reproducible
When random generation algorithm is given the same PRNG with the same seed, it always outputs the same scalar on all platforms
If you don’t need constant-time/reproducibility properties, you can use random_vartime instead which is typically faster.
Panics
Panics if randomness source returned 100 zero scalars in a row. It happens with negligible probability, e.g. for secp256k1 curve it’s about $2^{-25600}$, which practically means that randomness source is broken.
we use rejection-sampling strategy in case if a zero scalar is generated, however, probability of that happening is negligible ↩
Sourcepub fn random_vartime<R: RngCore>(rng: &mut R) -> Self
pub fn random_vartime<R: RngCore>(rng: &mut R) -> Self
Generates random non-zero scalar using variable time algorithm
Guarantees
- Uniform distribution
Output scalar is uniformly distributed (given that provided PRNG outputs uniformly distributed bytes), with possible negligible bias respective to curve target security level
Unlike random method, this one is not constant-time nor reproducible, but
often it’s faster.
Panics
Panics if randomness source returned 100 zero scalars in a row. It happens with negligible probability, e.g. for secp256k1 curve it’s about $2^{-25600}$, which practically means that randomness source is broken.
Sourcepub fn from_hash<D: Digest>(data: &impl Digestable) -> Self
Available on crate feature hash-to-scalar only.
pub fn from_hash<D: Digest>(data: &impl Digestable) -> Self
hash-to-scalar only.Hashes the input and outputs scalar
Input can be any structured data that implements Digestable
trait (see udigest crate).
How it works
It works by instantiating HashRng CSPRNG seeded from provided data.
Then it’s used to derive the scalar.
Security considerations
It’s not constant time. It doesn’t follow any existing standards for hash to scalar primitive.
Example
use generic_ec::{Scalar, NonZero, curves::Secp256k1};
use sha2::Sha256;
#[derive(udigest::Digestable)]
struct Data<'a> {
nonce: &'a [u8],
param_a: &'a str,
param_b: u128,
// ...
}
let scalar = NonZero::<Scalar<Secp256k1>>::from_hash::<Sha256>(&Data {
nonce: b"some data",
param_a: "some other data",
param_b: 12345,
// ...
});Sourcepub fn from_scalar(scalar: Scalar<E>) -> Option<Self>
pub fn from_scalar(scalar: Scalar<E>) -> Option<Self>
Constructs non-zero scalar
Returns None if scalar is zero
Sourcepub fn ct_from_scalar(scalar: Scalar<E>) -> CtOption<Self>
pub fn ct_from_scalar(scalar: Scalar<E>) -> CtOption<Self>
Constructs non-zero scalar (constant time)
Returns None if scalar is zero
Sourcepub fn invert(&self) -> NonZero<Scalar<E>>
pub fn invert(&self) -> NonZero<Scalar<E>>
Returns scalar inverse $S^{-1}$
Similar to Scalar::invert, but this function is always defined as inverse is defined for all non-zero scalars
Sourcepub fn into_secret(self) -> NonZero<SecretScalar<E>>
pub fn into_secret(self) -> NonZero<SecretScalar<E>>
Upgrades the non-zero scalar into non-zero SecretScalar
Sourceimpl<E: Curve> NonZero<SecretScalar<E>>
impl<E: Curve> NonZero<SecretScalar<E>>
Sourcepub fn random<R: RngCore + CryptoRng>(rng: &mut R) -> Self
pub fn random<R: RngCore + CryptoRng>(rng: &mut R) -> Self
Generates random non-zero scalar
Guarantees
- Uniform distribution
Output scalar is uniformly distributed (given that provided PRNG outputs uniformly distributed bytes), with possible negligible bias respective to curve target security level - Constant-time
Random generation algorithm does not branch on input randomness, and in particular, it does not use rejection-sampling strategy (might not be the case with negligible probability respective to the curve target security level1) - Reproducible
When random generation algorithm is given the same PRNG with the same seed, it always outputs the same scalar on all platforms
If you don’t need constant-time/reproducibility properties, you can use random_vartime instead which is typically faster.
Panics
Panics if randomness source returned 100 zero scalars in a row. It happens with negligible probability, e.g. for secp256k1 curve it’s about $2^{-25600}$, which practically means that randomness source is broken.
we use rejection-sampling strategy in case if a zero scalar is generated, however, probability of that happening is negligible ↩
Sourcepub fn random_vartime<R: RngCore + CryptoRng>(rng: &mut R) -> Self
pub fn random_vartime<R: RngCore + CryptoRng>(rng: &mut R) -> Self
Generates random non-zero scalar using variable time algorithm
Guarantees
- Uniform distribution
Output scalar is uniformly distributed (given that provided PRNG outputs uniformly distributed bytes), with possible negligible bias respective to curve target security level
Unlike random method, this one is not constant-time nor reproducible, but
often it’s faster.
Panics
Panics if randomness source returned 100 zero scalars in a row. It happens with negligible probability, e.g. for secp256k1 curve it’s about $2^{-25600}$, which practically means that randomness source is broken.
Sourcepub fn from_secret_scalar(scalar: SecretScalar<E>) -> Option<Self>
pub fn from_secret_scalar(scalar: SecretScalar<E>) -> Option<Self>
Constructs non-zero scalar
Returns None if scalar is zero
Sourcepub fn ct_from_secret_scalar(secret_scalar: SecretScalar<E>) -> CtOption<Self>
pub fn ct_from_secret_scalar(secret_scalar: SecretScalar<E>) -> CtOption<Self>
Constructs non-zero scalar (constant time)
Returns None if scalar is zero
Sourcepub fn invert(&self) -> NonZero<SecretScalar<E>>
pub fn invert(&self) -> NonZero<SecretScalar<E>>
Returns scalar inverse $S^{-1}$
Similar to SecretScalar::invert, but this function is always defined as inverse is defined for all non-zero scalars