SecretPoint

Struct SecretPoint 

pub struct SecretPoint<E: Curve>(/* private fields */);
Point representing sensitive information (like a derived secret)

Secret point should be treated with an extra care. You shouldn’t do any branching (e.g. Eq, Ord) on the secret to avoid timing side-channel attacks, so it implements only constant time traits (like ConstantTimeEq).

Also, when alloc feature is enabled, we enforce extra measures:

  • Secret point leaves no trace in RAM after it’s dropped
    Memory is zeroized after use
  • All clones of a secret point refer to the same region in the memory
    I.e. there will always be only one instance of the point in the memory no matter how many clones you make

All these guarantees can be bypassed by calling .as_ref() and obtaining &Point<E> that is not protected from timing attacks, leaving traces in the memory, etc.

Implementations

Source

impl<E: Curve> SecretPoint<E>

pub fn new(point: &mut Point<E>) -> Self

Constructs a new secret point

Takes the original point by mutable reference instead of taking by value to avoid leaving copies of the point on stack. Point behind the reference will be zeroized after the function has returned.

pub fn generator() -> Self

Returns the generator defined in the curve specs

pub fn zero() -> Self

Returns identity point $\O$

pub fn as_nonsecret(&self) -> &Point<E>

Obtain the reference to the point, which you can use for any operations necessary. This bypasses all the secrecy guarantees, so be careful when handling the resulting value; ideally this reference should not be held for longer than one expression

The AsRef impl uses this method under the hood, and is provided as a less explicit but very convenient alternative

pub fn to_bytes(&self, compressed: bool) -> EncodedSecretPoint<E>

Encodes a point as bytes

pub fn from_bytes(bytes: &[u8]) -> Result<Self, InvalidPoint>

Decodes a point from bytes